import * as cdk from "../../core";
import * as constructs from "constructs";
import * as cfn_parse from "../../core/lib/helpers-internal";
/**
 * Definition of AWS::DataZone::DataSource Resource Type.
 *
 * @cloudformationResource AWS::DataZone::DataSource
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html
 */
export declare class CfnDataSource extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnDataSource from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDataSource;
    /**
     * The timestamp of when the data source was created.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * The ID of the Amazon DataZone domain where the data source is created.
     *
     * @cloudformationAttribute DomainId
     */
    readonly attrDomainId: string;
    /**
     * The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
     *
     * @cloudformationAttribute EnvironmentId
     */
    readonly attrEnvironmentId: string;
    /**
     * The unique identifier of the data source.
     *
     * @cloudformationAttribute Id
     */
    readonly attrId: string;
    /**
     * The number of assets created by the data source during its last run.
     *
     * @cloudformationAttribute LastRunAssetCount
     */
    readonly attrLastRunAssetCount: cdk.IResolvable;
    /**
     * The timestamp that specifies when the data source was last run.
     *
     * @cloudformationAttribute LastRunAt
     */
    readonly attrLastRunAt: string;
    /**
     * The status of the last run of this data source.
     *
     * @cloudformationAttribute LastRunStatus
     */
    readonly attrLastRunStatus: string;
    /**
     * The ID of the Amazon DataZone project to which the data source is added.
     *
     * @cloudformationAttribute ProjectId
     */
    readonly attrProjectId: string;
    /**
     * The status of the data source.
     *
     * @cloudformationAttribute Status
     */
    readonly attrStatus: string;
    /**
     * The timestamp of when this data source was updated.
     *
     * @cloudformationAttribute UpdatedAt
     */
    readonly attrUpdatedAt: string;
    /**
     * The metadata forms that are to be attached to the assets that this data source works with.
     */
    assetFormsInput?: Array<CfnDataSource.FormInputProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * Specifies the configuration of the data source.
     */
    configuration?: CfnDataSource.DataSourceConfigurationInputProperty | cdk.IResolvable;
    /**
     * The description of the data source.
     */
    description?: string;
    /**
     * The ID of the Amazon DataZone domain where the data source is created.
     */
    domainIdentifier: string;
    /**
     * Specifies whether the data source is enabled.
     */
    enableSetting?: string;
    /**
     * The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
     */
    environmentIdentifier: string;
    /**
     * The name of the data source.
     */
    name: string;
    /**
     * The identifier of the Amazon DataZone project in which you want to add the data source.
     */
    projectIdentifier: string;
    /**
     * Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
     */
    publishOnImport?: boolean | cdk.IResolvable;
    /**
     * The recommendation to be updated as part of the UpdateDataSource action.
     */
    recommendation?: cdk.IResolvable | CfnDataSource.RecommendationConfigurationProperty;
    /**
     * The schedule of the data source runs.
     */
    schedule?: cdk.IResolvable | CfnDataSource.ScheduleConfigurationProperty;
    /**
     * The type of the data source.
     */
    type: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnDataSourceProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnDataSource {
    /**
     * The details of a metadata form.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-forminput.html
     */
    interface FormInputProperty {
        /**
         * The content of the metadata form.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-forminput.html#cfn-datazone-datasource-forminput-content
         */
        readonly content?: string;
        /**
         * The name of the metadata form.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-forminput.html#cfn-datazone-datasource-forminput-formname
         */
        readonly formName: string;
        /**
         * The ID of the metadata form type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-forminput.html#cfn-datazone-datasource-forminput-typeidentifier
         */
        readonly typeIdentifier?: string;
        /**
         * The revision of the metadata form type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-forminput.html#cfn-datazone-datasource-forminput-typerevision
         */
        readonly typeRevision?: string;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-datasourceconfigurationinput.html
     */
    interface DataSourceConfigurationInputProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-datasourceconfigurationinput.html#cfn-datazone-datasource-datasourceconfigurationinput-gluerunconfiguration
         */
        readonly glueRunConfiguration?: CfnDataSource.GlueRunConfigurationInputProperty | cdk.IResolvable;
        /**
         * The configuration details of the Amazon Redshift data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-datasourceconfigurationinput.html#cfn-datazone-datasource-datasourceconfigurationinput-redshiftrunconfiguration
         */
        readonly redshiftRunConfiguration?: cdk.IResolvable | CfnDataSource.RedshiftRunConfigurationInputProperty;
    }
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-gluerunconfigurationinput.html
     */
    interface GlueRunConfigurationInputProperty {
        /**
         * The data access role included in the configuration details of the AWS Glue data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-gluerunconfigurationinput.html#cfn-datazone-datasource-gluerunconfigurationinput-dataaccessrole
         */
        readonly dataAccessRole?: string;
        /**
         * The relational filter configurations included in the configuration details of the AWS Glue data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-gluerunconfigurationinput.html#cfn-datazone-datasource-gluerunconfigurationinput-relationalfilterconfigurations
         */
        readonly relationalFilterConfigurations: Array<cdk.IResolvable | CfnDataSource.RelationalFilterConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The relational filter configuration for the data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-relationalfilterconfiguration.html
     */
    interface RelationalFilterConfigurationProperty {
        /**
         * The database name specified in the relational filter configuration for the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-relationalfilterconfiguration.html#cfn-datazone-datasource-relationalfilterconfiguration-databasename
         */
        readonly databaseName: string;
        /**
         * The filter expressions specified in the relational filter configuration for the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-relationalfilterconfiguration.html#cfn-datazone-datasource-relationalfilterconfiguration-filterexpressions
         */
        readonly filterExpressions?: Array<CfnDataSource.FilterExpressionProperty | cdk.IResolvable> | cdk.IResolvable;
        /**
         * The schema name specified in the relational filter configuration for the data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-relationalfilterconfiguration.html#cfn-datazone-datasource-relationalfilterconfiguration-schemaname
         */
        readonly schemaName?: string;
    }
    /**
     * The search filter expression.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-filterexpression.html
     */
    interface FilterExpressionProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-filterexpression.html#cfn-datazone-datasource-filterexpression-expression
         */
        readonly expression: string;
        /**
         * The search filter expression type.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-filterexpression.html#cfn-datazone-datasource-filterexpression-type
         */
        readonly type: string;
    }
    /**
     * The configuration details of the Amazon Redshift data source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftrunconfigurationinput.html
     */
    interface RedshiftRunConfigurationInputProperty {
        /**
         * The data access role included in the configuration details of the AWS Glue data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftrunconfigurationinput.html#cfn-datazone-datasource-redshiftrunconfigurationinput-dataaccessrole
         */
        readonly dataAccessRole?: string;
        /**
         * The ARN of a secret manager for an Amazon Redshift cluster.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftrunconfigurationinput.html#cfn-datazone-datasource-redshiftrunconfigurationinput-redshiftcredentialconfiguration
         */
        readonly redshiftCredentialConfiguration: cdk.IResolvable | CfnDataSource.RedshiftCredentialConfigurationProperty;
        /**
         * The details of the Amazon Redshift storage as part of the configuration of an Amazon Redshift data source run.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftrunconfigurationinput.html#cfn-datazone-datasource-redshiftrunconfigurationinput-redshiftstorage
         */
        readonly redshiftStorage: cdk.IResolvable | CfnDataSource.RedshiftStorageProperty;
        /**
         * The relational filter configurations included in the configuration details of the Amazon Redshift data source.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftrunconfigurationinput.html#cfn-datazone-datasource-redshiftrunconfigurationinput-relationalfilterconfigurations
         */
        readonly relationalFilterConfigurations: Array<cdk.IResolvable | CfnDataSource.RelationalFilterConfigurationProperty> | cdk.IResolvable;
    }
    /**
     * The ARN of a secret manager for an Amazon Redshift cluster.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftcredentialconfiguration.html
     */
    interface RedshiftCredentialConfigurationProperty {
        /**
         * The ARN of a secret manager for an Amazon Redshift cluster.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftcredentialconfiguration.html#cfn-datazone-datasource-redshiftcredentialconfiguration-secretmanagerarn
         */
        readonly secretManagerArn: string;
    }
    /**
     * The details of the Amazon Redshift cluster source.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftstorage.html
     */
    interface RedshiftStorageProperty {
        /**
         * The name of an Amazon Redshift cluster.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftstorage.html#cfn-datazone-datasource-redshiftstorage-redshiftclustersource
         */
        readonly redshiftClusterSource?: cdk.IResolvable | CfnDataSource.RedshiftClusterStorageProperty;
        /**
         * The details of the Amazon Redshift Serverless workgroup storage.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftstorage.html#cfn-datazone-datasource-redshiftstorage-redshiftserverlesssource
         */
        readonly redshiftServerlessSource?: cdk.IResolvable | CfnDataSource.RedshiftServerlessStorageProperty;
    }
    /**
     * The name of an Amazon Redshift cluster.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftclusterstorage.html
     */
    interface RedshiftClusterStorageProperty {
        /**
         * The name of an Amazon Redshift cluster.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftclusterstorage.html#cfn-datazone-datasource-redshiftclusterstorage-clustername
         */
        readonly clusterName: string;
    }
    /**
     * The details of the Amazon Redshift Serverless workgroup storage.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftserverlessstorage.html
     */
    interface RedshiftServerlessStorageProperty {
        /**
         * The name of the Amazon Redshift Serverless workgroup.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-redshiftserverlessstorage.html#cfn-datazone-datasource-redshiftserverlessstorage-workgroupname
         */
        readonly workgroupName: string;
    }
    /**
     * The recommendation to be updated as part of the UpdateDataSource action.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-recommendationconfiguration.html
     */
    interface RecommendationConfigurationProperty {
        /**
         * Specifies whether automatic business name generation is to be enabled or not as part of the recommendation configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-recommendationconfiguration.html#cfn-datazone-datasource-recommendationconfiguration-enablebusinessnamegeneration
         */
        readonly enableBusinessNameGeneration?: boolean | cdk.IResolvable;
    }
    /**
     * The schedule of the data source runs.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-scheduleconfiguration.html
     */
    interface ScheduleConfigurationProperty {
        /**
         * The schedule of the data source runs.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-scheduleconfiguration.html#cfn-datazone-datasource-scheduleconfiguration-schedule
         */
        readonly schedule?: string;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-datasource-scheduleconfiguration.html#cfn-datazone-datasource-scheduleconfiguration-timezone
         */
        readonly timezone?: string;
    }
}
/**
 * Properties for defining a `CfnDataSource`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html
 */
export interface CfnDataSourceProps {
    /**
     * The metadata forms that are to be attached to the assets that this data source works with.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-assetformsinput
     */
    readonly assetFormsInput?: Array<CfnDataSource.FormInputProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * Specifies the configuration of the data source.
     *
     * It can be set to either glueRunConfiguration or redshiftRunConfiguration.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-configuration
     */
    readonly configuration?: CfnDataSource.DataSourceConfigurationInputProperty | cdk.IResolvable;
    /**
     * The description of the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-description
     */
    readonly description?: string;
    /**
     * The ID of the Amazon DataZone domain where the data source is created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-domainidentifier
     */
    readonly domainIdentifier: string;
    /**
     * Specifies whether the data source is enabled.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-enablesetting
     */
    readonly enableSetting?: string;
    /**
     * The unique identifier of the Amazon DataZone environment to which the data source publishes assets.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-environmentidentifier
     */
    readonly environmentIdentifier: string;
    /**
     * The name of the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-name
     */
    readonly name: string;
    /**
     * The identifier of the Amazon DataZone project in which you want to add the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-projectidentifier
     */
    readonly projectIdentifier: string;
    /**
     * Specifies whether the assets that this data source creates in the inventory are to be also automatically published to the catalog.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-publishonimport
     */
    readonly publishOnImport?: boolean | cdk.IResolvable;
    /**
     * The recommendation to be updated as part of the UpdateDataSource action.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-recommendation
     */
    readonly recommendation?: cdk.IResolvable | CfnDataSource.RecommendationConfigurationProperty;
    /**
     * The schedule of the data source runs.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-schedule
     */
    readonly schedule?: cdk.IResolvable | CfnDataSource.ScheduleConfigurationProperty;
    /**
     * The type of the data source.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-datasource.html#cfn-datazone-datasource-type
     */
    readonly type: string;
}
/**
 * A domain is an organizing entity for connecting together assets, users, and their projects.
 *
 * @cloudformationResource AWS::DataZone::Domain
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html
 */
export declare class CfnDomain extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnDomain from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnDomain;
    /**
     * The ARN of the Amazon DataZone domain.
     *
     * @cloudformationAttribute Arn
     */
    readonly attrArn: string;
    /**
     * The timestamp of when the Amazon DataZone domain was last updated.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * The id of the Amazon DataZone domain.
     *
     * @cloudformationAttribute Id
     */
    readonly attrId: string;
    /**
     * The timestamp of when the Amazon DataZone domain was last updated.
     *
     * @cloudformationAttribute LastUpdatedAt
     */
    readonly attrLastUpdatedAt: string;
    /**
     * The identifier of the AWS account that manages the domain.
     *
     * @cloudformationAttribute ManagedAccountId
     */
    readonly attrManagedAccountId: string;
    /**
     * The URL of the data portal for this Amazon DataZone domain.
     *
     * @cloudformationAttribute PortalUrl
     */
    readonly attrPortalUrl: string;
    /**
     * The status of the Amazon DataZone domain.
     *
     * @cloudformationAttribute Status
     */
    readonly attrStatus: string;
    /**
     * The description of the Amazon DataZone domain.
     */
    description?: string;
    /**
     * The domain execution role that is created when an Amazon DataZone domain is created.
     */
    domainExecutionRole: string;
    /**
     * The identifier of the AWS Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
     */
    kmsKeyIdentifier?: string;
    /**
     * The name of the Amazon DataZone domain.
     */
    name: string;
    /**
     * The single-sign on configuration of the Amazon DataZone domain.
     */
    singleSignOn?: cdk.IResolvable | CfnDomain.SingleSignOnProperty;
    /**
     * The tags specified for the Amazon DataZone domain.
     */
    tags?: Array<cdk.CfnTag>;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnDomainProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnDomain {
    /**
     * The single-sign on configuration of the Amazon DataZone domain.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-domain-singlesignon.html
     */
    interface SingleSignOnProperty {
        /**
         * The type of single sign-on in Amazon DataZone.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-domain-singlesignon.html#cfn-datazone-domain-singlesignon-type
         */
        readonly type?: string;
        /**
         * The single sign-on user assignment in Amazon DataZone.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-domain-singlesignon.html#cfn-datazone-domain-singlesignon-userassignment
         */
        readonly userAssignment?: string;
    }
}
/**
 * Properties for defining a `CfnDomain`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html
 */
export interface CfnDomainProps {
    /**
     * The description of the Amazon DataZone domain.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html#cfn-datazone-domain-description
     */
    readonly description?: string;
    /**
     * The domain execution role that is created when an Amazon DataZone domain is created.
     *
     * The domain execution role is created in the AWS account that houses the Amazon DataZone domain.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html#cfn-datazone-domain-domainexecutionrole
     */
    readonly domainExecutionRole: string;
    /**
     * The identifier of the AWS Key Management Service (KMS) key that is used to encrypt the Amazon DataZone domain, metadata, and reporting data.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html#cfn-datazone-domain-kmskeyidentifier
     */
    readonly kmsKeyIdentifier?: string;
    /**
     * The name of the Amazon DataZone domain.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html#cfn-datazone-domain-name
     */
    readonly name: string;
    /**
     * The single-sign on configuration of the Amazon DataZone domain.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html#cfn-datazone-domain-singlesignon
     */
    readonly singleSignOn?: cdk.IResolvable | CfnDomain.SingleSignOnProperty;
    /**
     * The tags specified for the Amazon DataZone domain.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-domain.html#cfn-datazone-domain-tags
     */
    readonly tags?: Array<cdk.CfnTag>;
}
/**
 * Definition of AWS::DataZone::Environment Resource Type.
 *
 * @cloudformationResource AWS::DataZone::Environment
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html
 */
export declare class CfnEnvironment extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnEnvironment from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnEnvironment;
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     *
     * @cloudformationAttribute AwsAccountId
     */
    readonly attrAwsAccountId: string;
    /**
     * The AWS region in which the Amazon DataZone environment is created.
     *
     * @cloudformationAttribute AwsAccountRegion
     */
    readonly attrAwsAccountRegion: string;
    /**
     * The timestamp of when the environment was created.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * The Amazon DataZone user who created the environment.
     *
     * @cloudformationAttribute CreatedBy
     */
    readonly attrCreatedBy: string;
    /**
     * The identifier of the Amazon DataZone domain in which the environment is created.
     *
     * @cloudformationAttribute DomainId
     */
    readonly attrDomainId: string;
    /**
     * The ID of the blueprint with which the Amazon DataZone environment was created.
     *
     * @cloudformationAttribute EnvironmentBlueprintId
     */
    readonly attrEnvironmentBlueprintId: string;
    /**
     * The ID of the environment profile with which the Amazon DataZone environment was created.
     *
     * @cloudformationAttribute EnvironmentProfileId
     */
    readonly attrEnvironmentProfileId: string;
    /**
     * The ID of the Amazon DataZone environment.
     *
     * @cloudformationAttribute Id
     */
    readonly attrId: string;
    /**
     * The ID of the Amazon DataZone project in which the environment is created.
     *
     * @cloudformationAttribute ProjectId
     */
    readonly attrProjectId: string;
    /**
     * The provider of the Amazon DataZone environment.
     *
     * @cloudformationAttribute Provider
     */
    readonly attrProvider: string;
    /**
     * The status of the Amazon DataZone environment.
     *
     * @cloudformationAttribute Status
     */
    readonly attrStatus: string;
    /**
     * The timestamp of when the environment was updated.
     *
     * @cloudformationAttribute UpdatedAt
     */
    readonly attrUpdatedAt: string;
    /**
     * The description of the Amazon DataZone environment.
     */
    description?: string;
    /**
     * The identifier of the Amazon DataZone domain in which the environment would be created.
     */
    domainIdentifier: string;
    /**
     * The ID of the environment profile with which the Amazon DataZone environment would be created.
     */
    environmentProfileIdentifier: string;
    /**
     * The glossary terms that can be used in the Amazon DataZone environment.
     */
    glossaryTerms?: Array<string>;
    /**
     * The name of the environment.
     */
    name: string;
    /**
     * The ID of the Amazon DataZone project in which the environment would be created.
     */
    projectIdentifier: string;
    /**
     * The user parameters of the Amazon DataZone environment.
     */
    userParameters?: Array<CfnEnvironment.EnvironmentParameterProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnEnvironmentProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnEnvironment {
    /**
     * The parameter details of an environment.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environment-environmentparameter.html
     */
    interface EnvironmentParameterProperty {
        /**
         * The name of an environment parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environment-environmentparameter.html#cfn-datazone-environment-environmentparameter-name
         */
        readonly name?: string;
        /**
         * The value of an environment parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environment-environmentparameter.html#cfn-datazone-environment-environmentparameter-value
         */
        readonly value?: string;
    }
}
/**
 * Properties for defining a `CfnEnvironment`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html
 */
export interface CfnEnvironmentProps {
    /**
     * The description of the Amazon DataZone environment.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html#cfn-datazone-environment-description
     */
    readonly description?: string;
    /**
     * The identifier of the Amazon DataZone domain in which the environment would be created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html#cfn-datazone-environment-domainidentifier
     */
    readonly domainIdentifier: string;
    /**
     * The ID of the environment profile with which the Amazon DataZone environment would be created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html#cfn-datazone-environment-environmentprofileidentifier
     */
    readonly environmentProfileIdentifier: string;
    /**
     * The glossary terms that can be used in the Amazon DataZone environment.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html#cfn-datazone-environment-glossaryterms
     */
    readonly glossaryTerms?: Array<string>;
    /**
     * The name of the environment.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html#cfn-datazone-environment-name
     */
    readonly name: string;
    /**
     * The ID of the Amazon DataZone project in which the environment would be created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html#cfn-datazone-environment-projectidentifier
     */
    readonly projectIdentifier: string;
    /**
     * The user parameters of the Amazon DataZone environment.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environment.html#cfn-datazone-environment-userparameters
     */
    readonly userParameters?: Array<CfnEnvironment.EnvironmentParameterProperty | cdk.IResolvable> | cdk.IResolvable;
}
/**
 * Definition of AWS::DataZone::EnvironmentBlueprintConfiguration Resource Type.
 *
 * @cloudformationResource AWS::DataZone::EnvironmentBlueprintConfiguration
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html
 */
export declare class CfnEnvironmentBlueprintConfiguration extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnEnvironmentBlueprintConfiguration from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnEnvironmentBlueprintConfiguration;
    /**
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * @cloudformationAttribute DomainId
     */
    readonly attrDomainId: string;
    /**
     * @cloudformationAttribute EnvironmentBlueprintId
     */
    readonly attrEnvironmentBlueprintId: string;
    /**
     * @cloudformationAttribute UpdatedAt
     */
    readonly attrUpdatedAt: string;
    domainIdentifier: string;
    enabledRegions: Array<string>;
    environmentBlueprintIdentifier: string;
    manageAccessRoleArn?: string;
    provisioningRoleArn?: string;
    regionalParameters?: Array<cdk.IResolvable | CfnEnvironmentBlueprintConfiguration.RegionalParameterProperty> | cdk.IResolvable;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnEnvironmentBlueprintConfigurationProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnEnvironmentBlueprintConfiguration {
    /**
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentblueprintconfiguration-regionalparameter.html
     */
    interface RegionalParameterProperty {
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentblueprintconfiguration-regionalparameter.html#cfn-datazone-environmentblueprintconfiguration-regionalparameter-parameters
         */
        readonly parameters?: cdk.IResolvable | Record<string, string>;
        /**
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentblueprintconfiguration-regionalparameter.html#cfn-datazone-environmentblueprintconfiguration-regionalparameter-region
         */
        readonly region?: string;
    }
}
/**
 * Properties for defining a `CfnEnvironmentBlueprintConfiguration`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html
 */
export interface CfnEnvironmentBlueprintConfigurationProps {
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html#cfn-datazone-environmentblueprintconfiguration-domainidentifier
     */
    readonly domainIdentifier: string;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html#cfn-datazone-environmentblueprintconfiguration-enabledregions
     */
    readonly enabledRegions: Array<string>;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html#cfn-datazone-environmentblueprintconfiguration-environmentblueprintidentifier
     */
    readonly environmentBlueprintIdentifier: string;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html#cfn-datazone-environmentblueprintconfiguration-manageaccessrolearn
     */
    readonly manageAccessRoleArn?: string;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html#cfn-datazone-environmentblueprintconfiguration-provisioningrolearn
     */
    readonly provisioningRoleArn?: string;
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentblueprintconfiguration.html#cfn-datazone-environmentblueprintconfiguration-regionalparameters
     */
    readonly regionalParameters?: Array<cdk.IResolvable | CfnEnvironmentBlueprintConfiguration.RegionalParameterProperty> | cdk.IResolvable;
}
/**
 * AWS Datazone Environment Profile is pre-configured set of resources and blueprints that provide reusable templates for creating environments.
 *
 * @cloudformationResource AWS::DataZone::EnvironmentProfile
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html
 */
export declare class CfnEnvironmentProfile extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnEnvironmentProfile from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnEnvironmentProfile;
    /**
     * The timestamp of when this environment profile was created.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * The Amazon DataZone user who created this environment profile.
     *
     * @cloudformationAttribute CreatedBy
     */
    readonly attrCreatedBy: string;
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     *
     * @cloudformationAttribute DomainId
     */
    readonly attrDomainId: string;
    /**
     * The ID of the blueprint with which this environment profile is created.
     *
     * @cloudformationAttribute EnvironmentBlueprintId
     */
    readonly attrEnvironmentBlueprintId: string;
    /**
     * The ID of this Amazon DataZone environment profile.
     *
     * @cloudformationAttribute Id
     */
    readonly attrId: string;
    /**
     * The identifier of the project in which to create the environment profile.
     *
     * @cloudformationAttribute ProjectId
     */
    readonly attrProjectId: string;
    /**
     * The timestamp of when this environment profile was updated.
     *
     * @cloudformationAttribute UpdatedAt
     */
    readonly attrUpdatedAt: string;
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    awsAccountId?: string;
    /**
     * The AWS region in which this environment profile is created.
     */
    awsAccountRegion?: string;
    /**
     * The description of this Amazon DataZone environment profile.
     */
    description?: string;
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     */
    domainIdentifier: string;
    /**
     * The ID of the blueprint with which this environment profile is created.
     */
    environmentBlueprintIdentifier: string;
    /**
     * The name of this Amazon DataZone environment profile.
     */
    name: string;
    /**
     * The identifier of the project in which to create the environment profile.
     */
    projectIdentifier: string;
    /**
     * The user parameters of this Amazon DataZone environment profile.
     */
    userParameters?: Array<CfnEnvironmentProfile.EnvironmentParameterProperty | cdk.IResolvable> | cdk.IResolvable;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnEnvironmentProfileProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnEnvironmentProfile {
    /**
     * The parameter details of an environment profile.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentprofile-environmentparameter.html
     */
    interface EnvironmentParameterProperty {
        /**
         * The name of an environment profile parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentprofile-environmentparameter.html#cfn-datazone-environmentprofile-environmentparameter-name
         */
        readonly name?: string;
        /**
         * The value of an environment profile parameter.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-environmentprofile-environmentparameter.html#cfn-datazone-environmentprofile-environmentparameter-value
         */
        readonly value?: string;
    }
}
/**
 * Properties for defining a `CfnEnvironmentProfile`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html
 */
export interface CfnEnvironmentProfileProps {
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-awsaccountid
     */
    readonly awsAccountId?: string;
    /**
     * The AWS region in which this environment profile is created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-awsaccountregion
     */
    readonly awsAccountRegion?: string;
    /**
     * The description of this Amazon DataZone environment profile.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-description
     */
    readonly description?: string;
    /**
     * The ID of the Amazon DataZone domain in which this environment profile is created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-domainidentifier
     */
    readonly domainIdentifier: string;
    /**
     * The ID of the blueprint with which this environment profile is created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-environmentblueprintidentifier
     */
    readonly environmentBlueprintIdentifier: string;
    /**
     * The name of this Amazon DataZone environment profile.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-name
     */
    readonly name: string;
    /**
     * The identifier of the project in which to create the environment profile.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-projectidentifier
     */
    readonly projectIdentifier: string;
    /**
     * The user parameters of this Amazon DataZone environment profile.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-environmentprofile.html#cfn-datazone-environmentprofile-userparameters
     */
    readonly userParameters?: Array<CfnEnvironmentProfile.EnvironmentParameterProperty | cdk.IResolvable> | cdk.IResolvable;
}
/**
 * Amazon DataZone projects are business use case–based groupings of people, assets (data), and tools used to simplify access to the AWS analytics.
 *
 * @cloudformationResource AWS::DataZone::Project
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-project.html
 */
export declare class CfnProject extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnProject from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnProject;
    /**
     * The timestamp of when the project was created.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * The Amazon DataZone user who created the project.
     *
     * @cloudformationAttribute CreatedBy
     */
    readonly attrCreatedBy: string;
    /**
     * The identifier of the Amazon DataZone domain in which the project was created.
     *
     * @cloudformationAttribute DomainId
     */
    readonly attrDomainId: string;
    /**
     * The ID of the Amazon DataZone project.
     *
     * @cloudformationAttribute Id
     */
    readonly attrId: string;
    /**
     * The timestamp of when the project was last updated.
     *
     * @cloudformationAttribute LastUpdatedAt
     */
    readonly attrLastUpdatedAt: string;
    /**
     * The description of the Amazon DataZone project.
     */
    description?: string;
    /**
     * The ID of the Amazon DataZone domain in which this project is created.
     */
    domainIdentifier: string;
    /**
     * The glossary terms that can be used in this Amazon DataZone project.
     */
    glossaryTerms?: Array<string>;
    /**
     * The name of the Amazon DataZone project.
     */
    name: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnProjectProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
/**
 * Properties for defining a `CfnProject`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-project.html
 */
export interface CfnProjectProps {
    /**
     * The description of the Amazon DataZone project.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-project.html#cfn-datazone-project-description
     */
    readonly description?: string;
    /**
     * The ID of the Amazon DataZone domain in which this project is created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-project.html#cfn-datazone-project-domainidentifier
     */
    readonly domainIdentifier: string;
    /**
     * The glossary terms that can be used in this Amazon DataZone project.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-project.html#cfn-datazone-project-glossaryterms
     */
    readonly glossaryTerms?: Array<string>;
    /**
     * The name of the Amazon DataZone project.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-project.html#cfn-datazone-project-name
     */
    readonly name: string;
}
/**
 * Subscription targets enables one to access the data to which you have subscribed in your projects.
 *
 * @cloudformationResource AWS::DataZone::SubscriptionTarget
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html
 */
export declare class CfnSubscriptionTarget extends cdk.CfnResource implements cdk.IInspectable {
    /**
     * The CloudFormation resource type name for this resource class.
     */
    static readonly CFN_RESOURCE_TYPE_NAME: string;
    /**
     * Build a CfnSubscriptionTarget from CloudFormation properties
     *
     * A factory method that creates a new instance of this class from an object
     * containing the CloudFormation properties of this resource.
     * Used in the @aws-cdk/cloudformation-include module.
     *
     * @internal
     */
    static _fromCloudFormation(scope: constructs.Construct, id: string, resourceAttributes: any, options: cfn_parse.FromCloudFormationOptions): CfnSubscriptionTarget;
    /**
     * The timestamp of when the subscription target was created.
     *
     * @cloudformationAttribute CreatedAt
     */
    readonly attrCreatedAt: string;
    /**
     * The Amazon DataZone user who created the subscription target.
     *
     * @cloudformationAttribute CreatedBy
     */
    readonly attrCreatedBy: string;
    /**
     * The ID of the Amazon DataZone domain in which subscription target is created.
     *
     * @cloudformationAttribute DomainId
     */
    readonly attrDomainId: string;
    /**
     * The ID of the environment in which subscription target is created.
     *
     * @cloudformationAttribute EnvironmentId
     */
    readonly attrEnvironmentId: string;
    /**
     * The ID of the subscription target.
     *
     * @cloudformationAttribute Id
     */
    readonly attrId: string;
    /**
     * The identifier of the project specified in the subscription target.
     *
     * @cloudformationAttribute ProjectId
     */
    readonly attrProjectId: string;
    /**
     * The timestamp of when the subscription target was updated.
     *
     * @cloudformationAttribute UpdatedAt
     */
    readonly attrUpdatedAt: string;
    /**
     * The Amazon DataZone user who updated the subscription target.
     *
     * @cloudformationAttribute UpdatedBy
     */
    readonly attrUpdatedBy: string;
    /**
     * The asset types that can be included in the subscription target.
     */
    applicableAssetTypes: Array<string>;
    /**
     * The authorized principals of the subscription target.
     */
    authorizedPrincipals: Array<string>;
    /**
     * The ID of the Amazon DataZone domain in which subscription target would be created.
     */
    domainIdentifier: string;
    /**
     * The ID of the environment in which subscription target would be created.
     */
    environmentIdentifier: string;
    /**
     * The manage access role that is used to create the subscription target.
     */
    manageAccessRole: string;
    /**
     * The name of the subscription target.
     */
    name: string;
    /**
     * The provider of the subscription target.
     */
    provider?: string;
    /**
     * The configuration of the subscription target.
     */
    subscriptionTargetConfig: Array<cdk.IResolvable | CfnSubscriptionTarget.SubscriptionTargetFormProperty> | cdk.IResolvable;
    /**
     * The type of the subscription target.
     */
    type: string;
    /**
     * @param scope Scope in which this resource is defined
     * @param id Construct identifier for this resource (unique in its scope)
     * @param props Resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnSubscriptionTargetProps);
    protected get cfnProperties(): Record<string, any>;
    /**
     * Examines the CloudFormation resource and discloses attributes
     *
     * @param inspector tree inspector to collect and process attributes
     */
    inspect(inspector: cdk.TreeInspector): void;
    protected renderProperties(props: Record<string, any>): Record<string, any>;
}
export declare namespace CfnSubscriptionTarget {
    /**
     * The details of the subscription target configuration.
     *
     * @struct
     * @stability external
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-subscriptiontarget-subscriptiontargetform.html
     */
    interface SubscriptionTargetFormProperty {
        /**
         * The content of the subscription target configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-subscriptiontarget-subscriptiontargetform.html#cfn-datazone-subscriptiontarget-subscriptiontargetform-content
         */
        readonly content: string;
        /**
         * The form name included in the subscription target configuration.
         *
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datazone-subscriptiontarget-subscriptiontargetform.html#cfn-datazone-subscriptiontarget-subscriptiontargetform-formname
         */
        readonly formName: string;
    }
}
/**
 * Properties for defining a `CfnSubscriptionTarget`
 *
 * @struct
 * @stability external
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html
 */
export interface CfnSubscriptionTargetProps {
    /**
     * The asset types that can be included in the subscription target.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-applicableassettypes
     */
    readonly applicableAssetTypes: Array<string>;
    /**
     * The authorized principals of the subscription target.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-authorizedprincipals
     */
    readonly authorizedPrincipals: Array<string>;
    /**
     * The ID of the Amazon DataZone domain in which subscription target would be created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-domainidentifier
     */
    readonly domainIdentifier: string;
    /**
     * The ID of the environment in which subscription target would be created.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-environmentidentifier
     */
    readonly environmentIdentifier: string;
    /**
     * The manage access role that is used to create the subscription target.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-manageaccessrole
     */
    readonly manageAccessRole: string;
    /**
     * The name of the subscription target.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-name
     */
    readonly name: string;
    /**
     * The provider of the subscription target.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-provider
     */
    readonly provider?: string;
    /**
     * The configuration of the subscription target.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-subscriptiontargetconfig
     */
    readonly subscriptionTargetConfig: Array<cdk.IResolvable | CfnSubscriptionTarget.SubscriptionTargetFormProperty> | cdk.IResolvable;
    /**
     * The type of the subscription target.
     *
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datazone-subscriptiontarget.html#cfn-datazone-subscriptiontarget-type
     */
    readonly type: string;
}
